<?php
/**
 * Schemas Template.
 *
 * @package Schema Pro
 * @since 1.1.0
 */

if ( ! class_exists( 'BSF_AIOSRS_Pro_Schema_Global_Site_Navigation_Element' ) ) {

	/**
	 * AIOSRS Schemas Initialization
	 *
	 * @since 1.1.0
	 */
	class BSF_AIOSRS_Pro_Schema_Global_Site_Navigation_Element {

		/**
		 * Render Schema.
		 *
		 * @param  array<string, mixed> $post Current Post Array.
		 * @return array<string, mixed>
		 */
		public static function render( array $post ): array {
			$schema = array();

			$names = array();
			$urls  = array();

			// Ensure BSF_AIOSRS_Pro_Helper::$settings is defined and has the expected structure.
			/** @var array{
			 *     'site-navigation-element'?: int|string|WP_Term
			 * } $global_schemas */
			$global_schemas = BSF_AIOSRS_Pro_Helper::$settings['wp-schema-pro-global-schemas'] ?? array();
			if ( isset( $global_schemas['site-navigation-element'] ) && ! empty( $global_schemas['site-navigation-element'] ) ) {
				$site_navigation_element = $global_schemas['site-navigation-element'];
				if ( is_int( $site_navigation_element ) || is_string( $site_navigation_element ) || $site_navigation_element instanceof WP_Term ) {
					$navigation_links = wp_get_nav_menu_items( $site_navigation_element );

					if ( $navigation_links ) {
						foreach ( $navigation_links as $link ) {
							$names[] = wp_strip_all_tags( $link->title );
							$urls[]  = esc_url( $link->url );
						}
					}
				}
			}

			/**
			 * Convert normal array into associative array
			 */
			$combine_array = array_combine( $names, $urls ) ?: array();
			$new_arr       = array();
			$j             = 0;
			foreach ( $combine_array as $key => $value ) {
				$new_arr[ $j ]['name'] = $key;
				$new_arr[ $j ]['url']  = $value;
				$j++;
			}

			$schema['@context'] = 'https://schema.org';

			foreach ( $new_arr as $key2 => $value2 ) {
				$schema['@graph'][ $key2 ]['@context'] = 'https://schema.org';
				$schema['@graph'][ $key2 ]['@type']    = 'SiteNavigationElement';
				$schema['@graph'][ $key2 ]['id']       = 'site-navigation';
				$schema['@graph'][ $key2 ]['name']     = $value2['name'];
				$schema['@graph'][ $key2 ]['url']      = $value2['url'];
			}

			return apply_filters( 'wp_schema_pro_global_schema_site_navigation_element', $schema, $post );
		}

	}
}
